@@ -293,7 +293,7 @@ class DataFrameWriter(FrameWriter, io.DataFrameWriter):
                 )
             )
         return key_or_name, v.to_numpy()
-                
+
     def _prep_arr(self, arr: ndarray, ch: ChannelPayload, col: str):
         ch_dt = ch.data_type.np
         if arr.dtype != ch_dt:
@@ -338,6 +338,9 @@ class BufferedDataFrameWriter(io.DataFrameWriter):
         self.size_threshold = size_threshold
         self.time_threshold = time_threshold
 
+    def _(self) -> io.DataFrameWriter:
+        return self
+
     def write(self, frame: DataFrame):
         self._buf = pd_concat([self._buf, frame], ignore_index=True)
         if self._exceeds_any:
@@ -355,7 +358,6 @@ class BufferedDataFrameWriter(io.DataFrameWriter):
         )
 
     def _flush(self):
-        print(len(self._buf))
         self._wrapped.write(self._buf)
         self._wrapped.commit()
         self.last_flush = TimeStamp.now()
